@@ -1,6 +1,7 @@
 import json
 
 from sym.cli.helpers.ec2.factory import get_ec2_client
+from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory
 
 from ...errors import BotoError, CliError, InstanceNotFound
 from ..boto import get_identity
@@ -9,7 +10,7 @@ from .model import CheckContext, CheckResult, SymCheck, failure, success
 
 class CallerIdentityCheck(SymCheck):
     def check(self, ctx: CheckContext) -> CheckResult:
-        client = ctx.options.create_saml_client(ctx.resource)
+        client = SAMLClientFactory.create_saml_client(ctx.resource, ctx.options)
         try:
             identity = get_identity(client)
             pretty = json.dumps(identity, indent=4, sort_keys=True)
@@ -20,7 +21,8 @@ class CallerIdentityCheck(SymCheck):
 
 class DescribeRegionsCheck(SymCheck):
     def check(self, ctx: CheckContext) -> CheckResult:
-        client = ctx.options.create_saml_client(ctx.resource)
+        client = SAMLClientFactory.create_saml_client(ctx.resource, ctx.options)
+
         try:
             ctx.regions = get_ec2_client(client).get_regions()
             return success(f"Found {len(ctx.regions)} regions")
@@ -33,7 +35,7 @@ class DescribeInstanceCheck(SymCheck):
         self.instance = instance
 
     def check(self, ctx: CheckContext) -> CheckResult:
-        client = ctx.options.create_saml_client(ctx.resource)
+        client = SAMLClientFactory.create_saml_client(ctx.resource, ctx.options)
         try:
             running_instance = get_ec2_client(client).load_instance_by_alias(
                 self.instance
