@@ -2,14 +2,14 @@ from abc import ABC, abstractmethod
 from dataclasses import dataclass, field
 from typing import Optional, Sequence
 
+from sym.cli.data.global_options_base import GlobalOptionsBase
 from sym.cli.errors import CliError
 from sym.cli.helpers.ec2.client import RunningInstance
-from sym.cli.helpers.global_options import GlobalOptions
 
 
 @dataclass
 class CheckContext:
-    options: GlobalOptions
+    options: GlobalOptionsBase
     resource: str
     regions: Sequence[str] = field(default_factory=list)
     running_instances: Sequence[RunningInstance] = field(default_factory=list)
