@@ -6,6 +6,7 @@ from typing import Iterator, Optional, TextIO
 from sym.cli.helpers.config import Config
 from sym.cli.helpers.contexts import push_env
 from sym.cli.helpers.os import find_command
+from sym.cli.saml_clients.aws_okta import AwsOkta
 
 
 class Sandbox:
@@ -58,3 +59,14 @@ class Sandbox:
     def push_home(self) -> Iterator[None]:
         with push_env("HOME", str(self.create_dir("home"))):
             yield
+
+    @contextmanager
+    def setup(self, set_org: Optional[bool] = True, set_client: Optional[bool] = True):
+        with self.push_xdg_config_home():
+            if set_client:
+                self.create_binary(f"bin/{AwsOkta.binary}")
+            with self.push_exec_path():
+                if set_org:
+                    Config.instance()["org"] = "sym"
+                    Config.instance()["email"] = "y@symops.io"
+                yield
